@@ -31,6 +31,8 @@ from unify.generalutils import json_to_csv
 from unify.generalutils import csv_to_json
 from unify.apiutils import remove_special
 from unify.assetaccess import AssetAccess
+from unify.graph import Graph
+from unify.hierarchies import Hierarchy
 
 
 class ApiManager:
@@ -53,6 +55,10 @@ class ApiManager:
 
             self.sources = Sources(cluster=cluster, props=self.properties)
 
+            self.graphs = Graph(cluster=cluster, props=self.properties)
+
+            self.hierarchies = Hierarchy(cluster=cluster, props=self.properties)
+
             self.cluster = cluster
 
             self.sources.evergreen_enabled = self.evergreen_enabled
@@ -62,6 +68,52 @@ class ApiManager:
         except Exception as error:
             raise error
 
+    def delete_source(self, org_id, source_id):
+
+        return self.sources.delete_source(
+            org_id=org_id,
+            source_id=source_id
+        )
+
+    def query_graph(self, org, graph, query, json_format):
+        """
+        Create a cypher query request
+        :param org: Org where the graph to be queried is stored
+        :param graph: Graph uuid to be queried
+        :param query: String that contains cypher query
+        :param json_format: return the results in a universal correctly json o json lines
+        :return:
+        """
+
+        return self.graphs.query_graph(
+            org_id=org,
+            graph=graph,
+            query=query,
+            json_format=json_format
+        )
+
+    def graphs_list(self, org):
+        """
+        Return the list of graphs on a given org
+        :param org: Org ID that wants to be queried
+        :return: Json list with graph on the org
+        """
+        return self.graphs.get_graphs_list(org_id=org)
+
+    def regular_pipeline_duplicate(self, org_id, pipeline_id, new_name):
+        """
+        Duplicate a given pipeline on the same org
+        :param org_id: Org id where the pipeline is stored
+        :param pipeline_id: Pipeline id that will be duplicated
+        :param new_name: The new pipeline's name
+        :return:
+        """
+        return self.pipelines.regular_duplicate(
+            org_id=org_id,
+            pipeline_id=pipeline_id,
+            new_name=new_name
+        )
+
     def import_source(self, content, orgid, name, type, encoding="UTF-8", chunks=10000):
         """
         Creates a new dataset with content. Option to chunk the amount of lines that the file will be partitioned
@@ -109,8 +161,16 @@ class ApiManager:
                 chunks=chunks
             )
 
-        else:
-            raise Exception("Unsupported type of source to be imported")
+        elif type == "split":
+            return self.sources.divide_dataset_in(
+                name=name,
+                org_id=orgid,
+                content=content,
+                encoding=encoding,
+                chunks=chunks
+            )
+
+        raise Exception("Unsupported type of source to be imported")
 
     def export_source(self, org_id, dataset_ids):
         """
@@ -603,6 +663,12 @@ class ApiManager:
                         )
                     )
 
+                    # self.create_map_attributes_without_download(
+                    #    component=component,
+                    #    org_id=org_id,
+                    #    pipeline_id=pipeline_id
+                    # )
+
                 if component["jsonClass"] == "JsonFunctionApply":
                     func_id = "{}.{}.{}".format(pipeline_id, component["id"], component["pipelineId"])
                     results["functions"][func_id] = json.loads(
@@ -701,6 +767,66 @@ class ApiManager:
 
         return pipeline_data, list(errors)
 
+    def mapped_rules_to_csv(self, rules):
+        full_json = []
+
+        if "distinctValues" in rules:
+            distinct = rules["distinctValues"]
+            if "cols" in distinct:
+                cols = distinct["cols"]
+
+                if "Count *" in cols:
+                    cols.remove("Count *")
+
+                if "data" in distinct:
+                    # we have data :)
+                    data = distinct["data"]
+                    if "rows" in data:
+                        raw_data = data["rows"]
+
+                        for row in raw_data:
+                            new_row = dict()
+
+                            for col in cols:
+                                new_row[col] = row[col]
+
+                            full_json.append(new_row)
+
+        return full_json
+
+    def create_map_attributes_without_download(self, component, org_id, pipeline_id):
+        if "displayInformation" in component:
+            try:
+                if component["displayInformation"] is not None:
+
+                    if "columns" in component["displayInformation"]:
+
+                        mapped_rules = self.pipelines.get_distinct_values_map_attributes(
+                            org_id=org_id,
+                            pipeline_id=pipeline_id,
+                            flows=component["mappedFlow"]["id"],
+                            columns=component["displayInformation"]["columns"]
+                        )
+
+                    else:
+                        mapped_rules = self.pipelines.get_distinct_values_map_attributes(
+                            org_id=org_id,
+                            pipeline_id=pipeline_id,
+                            flows=component["mappedFlow"]["id"],
+                            columns=[]
+                        )
+                else:
+                    mapped_rules = self.pipelines.get_distinct_values_map_attributes(
+                        org_id=org_id,
+                        pipeline_id=pipeline_id,
+                        flows=component["mappedFlow"]["id"],
+                        columns=[]
+                    )
+
+                return self.mapped_rules_to_csv(rules=mapped_rules)
+            except Exception as err:
+                pass
+
     def change_tempate_names_to_ids(self, pipeline_data, templates_data):
         """
         Change the templates names to its ids
@@ -888,7 +1014,8 @@ class ApiManager:
                                 )
 
                 if component["jsonClass"] == "JsonMapAttributes":
-                    data["map_recipes"][component["id"]] = data["map_attributes"][component["id"]]
+                    if component["id"] in data["map_attributes"]:
+                        data["map_recipes"][component["id"]] = data["map_attributes"][component["id"]]
 
                 if component["jsonClass"] == "JsonFunctionApply":
                     component["pipelineId"] = migrated_funcs[str(component["pipelineId"])]
@@ -901,7 +1028,6 @@ class ApiManager:
                     component["orgId"] = org_id
                     component["datasetId"] = str(uuid.uuid4())
 
-
             pipeline = self.pipelines.create_pipeline(
                 org_id=org_id,
                 name=data["pipeline"]["pipeline"]["data"]["name"],
@@ -918,12 +1044,15 @@ class ApiManager:
             )
 
             for component_id, recipe in data["map_recipes"].items():
-                self.pipelines.upload_map_attributes_from_json(
-                    org_id=org_id,
-                    component_id=component_id,
-                    pipeline_id=created_pipeline_id,
-                    json_data=recipe
-                )
+                try:
+                    self.pipelines.upload_map_attributes_from_json(
+                        org_id=org_id,
+                        component_id=component_id,
+                        pipeline_id=created_pipeline_id,
+                        json_data=recipe
+                    )
+                except Exception as err:
+                    errors.append(repr(err))
 
             if "sources" in data:
                 if "datasets" not in skip:
@@ -956,3 +1085,142 @@ class ApiManager:
             return json.dumps(results)
         except Exception as error:
             raise error
+
+    def get_all_hierarchies_display(self, org):
+        """
+        Method to retrieve all the organization on a given org
+        :param org: Organization id where the org is stored
+        :return:
+        """
+        columns = [
+            "id", "name"
+        ]
+
+        raw_data = self.get_all_hierarchies(org=org)
+
+        for data in raw_data:
+
+            for key in list(data.keys()):
+
+                if key not in columns:
+                    del data[key]
+
+        return raw_data
+
+    def get_single_hierarchy(self, org, hierarchy):
+        """
+        Method to retrieve all the data form a single hierarchy and remove unnecessary data to be displayed on the console
+        :param org: Organization id where the org is stored
+        :param hierarchy: Hierarchy id to be retrieved
+        :return:
+        """
+        try:
+            columns = [
+                "id", "name", "levels"
+            ]
+
+            raw_data = self.hierarchies.get_hierarchy(
+                org_id=org,
+                hierarchy_id=hierarchy
+            )["config"]
+
+            for key in list(raw_data.keys()):
+
+                if key not in columns:
+                    del raw_data[key]
+
+            return raw_data
+
+        except Exception as error:
+            raise error
+
+    def get_all_hierarchies(self, org):
+        """
+        Method to retrieve all the organization on a given org
+        :param org: Organization id where the org is stored
+        :return:
+        """
+        try:
+            return self.hierarchies.get_all_hierarchies(
+                org_id=org
+            )
+        except Exception as error:
+            raise error
+
+    def create_hierarchy(self, org, name, levels=None, attribute_names=None, private=False):
+        """
+        Method to create a new hierarchy on the given org
+        :param org: Organization id where the org would be saved
+        :param name: String name of the new hierarchy
+        :param levels: Array containing the level names
+        :param attribute_names:
+        :param private: Boolean value to specify if the hierarchy is private
+        :return:
+        """
+        try:
+            return self.hierarchies.create_hierarchy(
+                org_id=org,
+                name=name,
+                levels=levels if levels is not None else [],
+                attribute_names=attribute_names,
+                private=private
+            )
+        except Exception as error:
+            raise error
+
+    def export_hierarchy(self, org, hierarchy):
+        """
+        Method to extract the necessary information to export a hierarchy
+        :param org: organization id where the hierarchy currently is stored
+        :param hierarchy: hierarchy id to be exported
+        :return:
+        """
+        try:
+            data = self.get_single_hierarchy(
+                org=org,
+                hierarchy=hierarchy
+            )
+
+            full_data = {
+                "name": data["name"],
+                "levels": dict()
+            }
+
+            for level in data["levels"]:
+                full_data["levels"][level["index"]] = level['groupName']
+
+            return json.dumps(full_data)
+        except Exception as error:
+            raise error
+
+    def import_hierarchy(self, org, content):
+        """
+        Method to import a hierarchy, this should be used with the output of the export hierarchy
+        :param org: organization id where the new hierarchy will be saved
+        :param content: json object containing hierarchy data
+        :return:
+        """
+        try:
+            data = json.loads(content)
+            if "name" in data:
+
+                new_h = self.create_hierarchy(
+                    org=org,
+                    name=data["name"]
+                )
+
+                hierarchy_id = new_h["id"]
+
+                if "levels" in data:
+                    levels = data["levels"]
+
+                    for i in range(0, len(levels.keys())):
+
+                        self.hierarchies.add_level(
+                            org_id=org,
+                            hierarchy_id=hierarchy_id,
+                            level_name=levels[str(i)]
+                        )
+
+        except Exception as error:
+            raise error
