@@ -16,9 +16,12 @@
 Contains general class to inherit from when creating a new api
 client service
 """
+import time
+
 import json
 import requests
 
+
 class ApiRequestManager:
     """
     Class to interact with general api request methods
@@ -36,11 +39,37 @@ class ApiRequestManager:
         self.props = props
         self.session = requests.Session()
         self.content_type_header = {"content-type": "application/json"}
+        self.content_octet = {"content-type": "application/octet-stream"}
+        self.upload_content_type_header = {"Content-Type": "multipart/form-data"}
+        self.delete_content_type_header = {"Content-Type": "application/json"}
+
+        self.list_templates_uri = 'api/assetTemplates'
+
         self.x_auth_token_header = "x-auth-token"
         self.x_org_header = "x-organization-id"
         self.cluster = cluster
         self.evergreen_enabled = True
 
+        self.epoch_time = int(time.time())
+        self.pi_tag_export_limit = {"piTagExportLimit": 999}
+        self.expiry = {"expiry": 999}
+
+        auth = self.props.get_auth_token(cluster=self.cluster)
+
+        self.api_session_url = self.props.get_remote(cluster=self.cluster) + 'api/sessions'
+
+        if auth is None or len(auth) == 0:
+            self.props.set_auth_token(
+                token=self.auth_token(),
+                cluster=self.cluster
+            )
+
+        self.session.headers.update(
+            {
+                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
+            }
+        )
+
     def close_session(self):
         """
         Closes request session
@@ -93,19 +122,14 @@ class ApiRequestManager:
         try:
             data = {"email": username, "password": password}
 
-            url = '{}api/sessions'.format(
-                self.props.get_remote(cluster=self.cluster)
-            )
-
             post_response = self.session.post(
-                url,
+                self.api_session_url,
                 headers=self.content_type_header,
                 data=json.dumps(data),
                 params=query_params
             )
 
             if post_response.status_code == 200:
-
                 return json.loads(post_response.content)["authToken"]
 
             raise Exception(post_response.content)
@@ -126,7 +150,7 @@ class ApiRequestManager:
         :type others: dict
         :return:
         """
-        header = dict()
+        header = {}
 
         if others is not None and isinstance(others, dict):
             header.update(others)
