@@ -47,16 +47,8 @@ class Sources(ApiRequestManager):
 
         super().__init__(cluster=cluster, props=props)
 
-        self.epoch_time = int(time.time())
-        self.pi_tag_export_limit = {"piTagExportLimit": 999}
-        self.expiry = {"expiry": 999}
-
         try:
 
-            self.list_templates_uri = 'api/assetTemplates'
-            self.upload_content_type_header = {"Content-Type": "multipart/form-data"}
-            self.delete_content_type_header = {"Content-Type": "application/json"}
-
             self.epoch_time = int(time.time())
             self.sources_url = self.props.get_remote(self.cluster) + "io/v1/org/{}/sources"
 
@@ -65,7 +57,7 @@ class Sources(ApiRequestManager):
             self.piwebapi_test_url = self.agents_url + "piwebapi/org/{}/test"
 
             self.piwebapi_create_url = self.agents_url + \
-                "piwebapi/org/{}/create?modeldata_only=true"
+                                       "piwebapi/org/{}/create?modeldata_only=true"
 
             self.piconfig_upload_url = self.agents_url + "piconfig/org/{}/model/?name=&serverName="
 
@@ -73,9 +65,7 @@ class Sources(ApiRequestManager):
 
             self.staticfile_upload_url = self.agents_url + "staticfile/org/{}/model"
 
-            self.delete_source_url = self.sources_url + "/{}"
-
-            self.delete_evergreening_source_url = self.agents_url + "piwebapi/org/{}/source/{}"
+            self.delete_source_url = self.agents_url + "piwebapi/org/{}/source/{}"
 
             self.stage_file_url = self.props.get_remote(self.cluster) + "datasets/v1/stage/file"
 
@@ -163,9 +153,70 @@ class Sources(ApiRequestManager):
             expected="Completed"
         )
 
+    def divide_dataset_in(
+            self, name, org_id, content, format="csv",
+            convert_to_parquet="false", encoding='UTF-8', chunks=10000):
+        """
+        Upload a dataset through the static route. This method should be used when
+        uploading a big file. It will split the file into
+        smaller chunks and upload them sequentially.
+
+        :param name: Dataset name to be cerated
+        :type name: str
+        :param org_id: Org where the dataset will be created
+        :type org_id: int or str
+        :param content: Dataset content
+        :type content: str
+        :param format: File format. Accepts "CSV" or "TSV"
+        :type format: str, optional
+        :param convert_to_parquet: Flag to convert file to parquet
+        :type convert_to_parquet: bool, optional
+        :param encoding: File encoding
+        :type encoding: str, optional
+        :param chunks: Number of chunks to split the file
+        :type chunks: int
+        :return:
+        """
+
+        data = content.encode(encoding)
+
+        jdata = csv_to_json(data)
+
+        dataset_data = {}
+        index = 0
+        for aux_file in stream_iterable(container=jdata, chunk=chunks):
+            aux_name = "{}_{}".format(name, index)
+
+            file_dir, path = mkstemp(suffix=".csv")
+
+            open(path, "w+").write(json_to_csv(aux_file))
+
+            dataset_data[aux_name] = self.create_api_data_set(
+                name=aux_name,
+                org_id=org_id,
+                file_path=path,
+                format=format,
+                convert_to_parquet=convert_to_parquet,
+                encoding=encoding
+            )
+            print(dataset_data[aux_name])
+
+            Wait().until(
+                self.is_commit_completed,
+                "commit {} never completed".format(dataset_data[aux_name]["data_set_id"]),
+                org_id,
+                dataset_data[aux_name]["data_set_id"],
+                dataset_data[aux_name]["commit_id"]
+            )
+
+            os.close(file_dir)
+            index += 1
+
+        return dataset_data
+
     def upload_big_dataset(
             self, name, org_id, content, format="csv",
-            convert_to_parquet="false", encoding='UTF-8',chunks=10000):
+            convert_to_parquet="false", encoding='UTF-8', chunks=10000):
         """
         Upload a dataset through the static route. This method should be used when
         uploading a big file. It will split the file into
@@ -255,9 +306,7 @@ class Sources(ApiRequestManager):
                     os.close(file_dir)
 
                 except Exception as err:
-                    print(err)
-                    open("fail_{} {}.csv".format(name, str(uuid.uuid4())[:4]), "wb").write(
-                        json_to_csv(aux_file).encode("utf-8"))
+                    return repr(err)
 
         return dataset_data
 
@@ -537,7 +586,6 @@ class Sources(ApiRequestManager):
 
         return response
 
-
     def _commit_dataset_command(self, org_id, data_set_id, command):
         header = self.build_header(
             org_id=org_id,
@@ -568,7 +616,6 @@ class Sources(ApiRequestManager):
         command = {"commands": [{"$type": "truncate", "cause": []}]}
         return self._commit_dataset_command(org_id, data_set_id, command)
 
-
     def append_dataset(self, org_id, data_set_id, content):
         """
         Appends data to existing dataset.
@@ -607,6 +654,13 @@ class Sources(ApiRequestManager):
         raise Exception(repr(post_upload_file.content))
 
     def label(self, org_id, data_set_id, labels):
+        """
+        Method to create dataset event object
+        :param org_id: Org where the event will be applied
+        :param data_set_id: dataset identification where the event would be applied
+        :param labels: labels that will be added to this event
+        :return:
+        """
         command = {
             "commands":
                 [
@@ -647,7 +701,6 @@ class Sources(ApiRequestManager):
         }
         return self._commit_dataset_command(org_id, data_set_id, command)
 
-
     def stage_data(
             self, name, org_id, file_path, group_id=None, format="csv",
             convert_to_parquet="false", encoding='UTF-8', encode=False):
@@ -974,3 +1027,35 @@ class Sources(ApiRequestManager):
             return content
 
         raise Exception(repr(get_sources_request.content))
+
+    def delete_source(self, org_id, source_id):
+
+        """
+        This method deletes a dataset that is stored on the org_id with the given source_id
+        :param org_id: Organization ID where the datasets is stored
+        :type org_id: int or str
+        :param source_id: Data set id to be deleted
+        :type source_id: str
+        :return: Result of the delete operation {"message":"Success","metadata":{}}
+        :raise: Exception when response code is not 200 or 201
+        """
+
+        headers = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            org_id=org_id,
+            others=self.content_type_header
+
+        )
+
+        delete_request = self.session.delete(
+            self.delete_source_url.format(
+                str(org_id),
+                source_id
+            ),
+            headers=headers
+        )
+
+        if delete_request.status_code in [200, 201]:
+            return json.loads(delete_request.content)
+
+        raise Exception(json.loads(delete_request.content))
